From cb2eb838cd381921e6af7f7c1f86c36323892909 Mon Sep 17 00:00:00 2001
From: Andreas Kloeckner <inform@tiker.net>
Date: Sun, 23 Sep 2012 22:26:01 -0500
Subject: [PATCH] Remove a few stray PyCUDA references. :)

---
 src/wrapper/_pvt_struct_v2.cpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/wrapper/_pvt_struct_v2.cpp b/src/wrapper/_pvt_struct_v2.cpp
index 31a16a82..e7a1c05a 100644
--- a/src/wrapper/_pvt_struct_v2.cpp
+++ b/src/wrapper/_pvt_struct_v2.cpp
@@ -5,7 +5,7 @@
 
 /* Compared with vanilla Python's struct module, this adds support
  * for packing complex values and only supports native packing.
  * (the minimum that's needed for PyCUDA.) */
 
 #define PY_SSIZE_T_CLEAN
 
@@ -1562,7 +1562,7 @@ init_pvt_struct(void)
 
 	/* Add some symbolic constants to the module */
 	if (StructError == NULL) {
-		StructError = PyErr_NewException("pycuda._pvt_struct.error", NULL, NULL);
+		StructError = PyErr_NewException("pyopencl._pvt_struct.error", NULL, NULL);
 		if (StructError == NULL)
 			return;
 	}
@@ -5,7 +5,7 @@
 /* Compared with vanilla Python's struct module, this adds support
  * for packing complex values and only supports native packing.
- * (the minimum that's needed for PyCUDA.) */
+ * (the minimum that's needed for PyOpenCL.) */
 
 #define PY_SSIZE_T_CLEAN
-- 
GitLab